@@ -317,19 +317,13 @@ def build_js():
             return os.stat(join("bokehjs", "build", *path)).st_size / 2**10
 
         print("  - bokeh.js              : %6.1f KB" % size("js", "bokeh.js"))
-        print("  - bokeh.css             : %6.1f KB" % size("css", "bokeh.css"))
         print("  - bokeh.min.js          : %6.1f KB" % size("js", "bokeh.min.js"))
-        print("  - bokeh.min.css         : %6.1f KB" % size("css", "bokeh.min.css"))
 
         print("  - bokeh-widgets.js      : %6.1f KB" % size("js", "bokeh-widgets.js"))
-        print("  - bokeh-widgets.css     : %6.1f KB" % size("css", "bokeh-widgets.css"))
         print("  - bokeh-widgets.min.js  : %6.1f KB" % size("js", "bokeh-widgets.min.js"))
-        print("  - bokeh-widgets.min.css : %6.1f KB" % size("css", "bokeh-widgets.min.css"))
 
         print("  - bokeh-tables.js       : %6.1f KB" % size("js", "bokeh-tables.js"))
-        print("  - bokeh-tables.css      : %6.1f KB" % size("css", "bokeh-tables.css"))
         print("  - bokeh-tables.min.js   : %6.1f KB" % size("js", "bokeh-tables.min.js"))
-        print("  - bokeh-tables.min.css  : %6.1f KB" % size("css", "bokeh-tables.min.css"))
 
         print("  - bokeh-api.js          : %6.1f KB" % size("js", "bokeh-api.js"))
         print("  - bokeh-api.min.js      : %6.1f KB" % size("js", "bokeh-api.min.js"))
