@@ -139,18 +139,12 @@ def test_get_svgs_with_svg_present(webdriver):
     svg2 = (
         '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" '
         'width="20" height="20" style="width: 20px; height: 20px;">'
-        '<defs>'
-            '<clipPath id="X"><path fill="none" stroke="none" d=" M 5 5 L 15 5 L 15 15 L 5 15 L 5 5 Z"/></clipPath>'
-            '<clipPath id="X"><path fill="none" stroke="none" d=" M 5 5 L 15 5 L 15 15 L 5 15 L 5 5 Z"/></clipPath>'
-        '</defs>'
+        '<defs/>'
         '<g>'
             '<g transform="scale(1,1) translate(0.5,0.5)">'
                 '<rect fill="#FFFFFF" stroke="none" x="0" y="0" width="20" height="20"/>'
                 '<rect fill="red" stroke="none" x="5" y="5" width="10" height="10"/>'
                 '<g/>'
-                '<g clip-path="url(#X)"><g/></g>'
-                '<g clip-path="url(#X)"><g/></g>'
-                '<g/>'
             '</g>'
         '</g>'
         '</svg>'
