@@ -5,7 +5,7 @@ from bokeh.models import Renderer
 
 class WaterfallRenderer(Renderer):
 
-    __implementation__ = join(dirname(__file__), "waterfall.coffee")
+    __implementation__ = join(dirname(__file__), "waterfall.ts")
 
     latest = Seq(Float)
 
