@@ -1,10 +1,10 @@
 from __future__ import absolute_import
 
 from bokeh.io import save
-from bokeh.models.widgets import MultiSelect, Panel, Tabs
+from bokeh.models import Tabs
+from bokeh.models.widgets import MultiSelect
 
 select = MultiSelect(options=["First option", "Second option"])
-panel = Panel(title="A tab", child=select)
-tabs = Tabs(tabs=[panel], width=300)
+tabs = Tabs(tabs=[("A tab", select)], width=300)
 
 save(tabs)
