@@ -1,5 +1,4 @@
 from bokeh.io import show, output_file
-from bokeh.models import ColumnDataSource
 from bokeh.palettes import Spectral5
 from bokeh.plotting import figure
 from bokeh.sampledata.autompg import autompg as df
@@ -10,14 +9,12 @@ output_file("bar_pandas_groupby_colormapped.html")
 df.cyl = df.cyl.astype(str)
 group = df.groupby('cyl')
 
-source = ColumnDataSource(group)
-
 cyl_cmap = factor_cmap('cyl', palette=Spectral5, factors=sorted(df.cyl.unique()))
 
 p = figure(plot_height=350, x_range=group, title="MPG by # Cylinders",
            toolbar_location=None, tools="")
 
-p.vbar(x='cyl', top='mpg_mean', width=1, source=source,
+p.vbar(x='cyl', top='mpg_mean', width=1, source=group,
        line_color=cyl_cmap, fill_color=cyl_cmap)
 
 p.y_range.start = 0
