@@ -1,6 +1,5 @@
 from bokeh.core.properties import value
 from bokeh.io import show, output_file
-from bokeh.models import ColumnDataSource, HoverTool
 from bokeh.plotting import figure
 
 output_file("bar_stacked.html")
@@ -14,21 +13,11 @@ data = {'fruits' : fruits,
         '2016'   : [5, 3, 4, 2, 4, 6],
         '2017'   : [3, 2, 4, 4, 5, 3]}
 
-source = ColumnDataSource(data=data)
+p = figure(x_range=fruits, plot_height=250, title="Fruit Counts by Year",
+           toolbar_location=None, tools="hover", tooltips="$name @fruits: @$name")
 
-p = figure(x_range=fruits, plot_height=350, title="Fruit Counts by Year",
-           toolbar_location=None, tools="")
-
-renderers = p.vbar_stack(years, x='fruits', width=0.9, color=colors, source=source,
-                         legend=[value(x) for x in years], name=years)
-
-for r in renderers:
-    year = r.name
-    hover = HoverTool(tooltips=[
-        ("%s total" % year, "@%s" % year),
-        ("index", "$index")
-    ], renderers=[r])
-    p.add_tools(hover)
+p.vbar_stack(years, x='fruits', width=0.9, color=colors, source=data,
+             legend=[value(x) for x in years])
 
 p.y_range.start = 0
 p.x_range.range_padding = 0.1
