@@ -27,11 +27,11 @@ xprime = np.cos(theta) * x - np.sin(theta) * y
 
 colors = ["#C6DBEF", "#9ECAE1", "#6BAED6", "#4292C6", "#2171B5", "#08519C", "#08306B",]
 
-p = figure(title="lorenz example")
+p = figure(title="Lorenz attractor example", background_fill_color="#fafafa")
 
 p.multi_line(np.array_split(xprime, 7), np.array_split(z, 7),
              line_color=colors, line_alpha=0.8, line_width=1.5)
 
 output_file("lorenz.html", title="lorenz.py example")
 
-show(p)  # open a browser
+show(p)
