@@ -14,7 +14,7 @@ source = ColumnDataSource(dict(x=x, y=y, markers=markers))
 
 plot = Plot(
     title=None, plot_width=300, plot_height=300,
-    h_symmetry=False, v_symmetry=False, min_border=0, toolbar_location=None)
+    min_border=0, toolbar_location=None)
 
 glyph = Scatter(x="x", y="y", size=20, fill_color="#74add1", marker="markers")
 plot.add_glyph(source, glyph)
