@@ -2,11 +2,10 @@ from __future__ import print_function
 
 import os
 import pytest
-import unittest
 import subprocess
 
 @pytest.mark.js
-class TestBokehJS(unittest.TestCase):
+class TestBokehJS(object):
 
     def test_bokehjs(self):
         os.chdir('bokehjs')
@@ -17,6 +16,3 @@ class TestBokehJS(unittest.TestCase):
         print(msg)
         if proc.returncode != 0:
             assert False
-
-if __name__ == "__main__":
-    unittest.main()
